@@ -569,10 +569,10 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     # set the upload path to the home directory
     UPLOAD_CODE_PATH = "$HOME/" + appname 
     cmd = "mkdir -p " + UPLOAD_CODE_PATH + "/" + APP_UTILS_DIR
-    sudo(cmd)
+    run(cmd)
     with cd('%s' % UPLOAD_CODE_PATH):
         put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=True)
-        run('tar zxf %s.tar.gz' % TAR_NAME)
+        run('tar zxf %s.tar.gz -C %s' % (TAR_NAME, APP_UTILS_DIR))
 
     # run the "instanceType"-command.sh in the appropriate branch
     cmdToRun = "$HOME/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
